pecos.error\_models.generic\_error\_model
=========================================

.. automodule:: pecos.error_models.generic_error_model











   .. rubric:: Classes

   .. autosummary::

      GenericErrorModel
